@@ -1,7 +1,7 @@
 /*
  *  This file is part of gpw.
  *
- *  Copyright (C) 2013-2014 Bruce Korb, all rights reserved.
+ *  Copyright (C) 2013-2015 Bruce Korb, all rights reserved.
  *  This is free software. It is licensed for use, modification and
  *  redistribution under the terms of the GNU General Public License,
  *  version 3 or later <http://gnu.org/licenses/gpl.html>
@@ -20,6 +20,8 @@
  *  with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef SORT_PW_CFG // code for gnu-pw-mgr only
+
 /**
  * Gain access to the config file.  \a set_config_name must have been
  * called previously.  This function figures out the current size and
@@ -43,8 +45,9 @@ access_config_file(void)
             (unsigned int)(sbf.st_mode & secure_mask));
 
     config_file_size = sbf.st_size;
-            
-    chmod(config_file_name, S_IWUSR | S_IRUSR);
+
+    if (chmod(config_file_name, S_IWUSR | S_IRUSR) != 0)
+        fserr(GNU_PW_MGR_EXIT_BAD_CONFIG, cfg_immutable, config_file_name);
 
     return config_file_name;
 }
@@ -87,7 +90,7 @@ load_config_file(void)
     char * dta;
     if (config_file_data != empty)
         free((void *)config_file_data);
-    
+
     (void) access_config_file();
     if (config_file_size == 0) {
         config_file_data = empty;
@@ -122,6 +125,7 @@ load_config_file(void)
 
 #define config_file_name config_file_name used in invalid context
 #define config_file_size config_file_size used in invalid context
+#endif // not SORT_PW_CFG only
 
 /**
  * Find the user's home directory.  There are two implementations.
